/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.client_attribute.grpc;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.apilib.client_attribute.OzgCloudBooleanClientAttribute;
import de.ozgcloud.apilib.client_attribute.OzgCloudDoubleClientAttribute;
import de.ozgcloud.apilib.client_attribute.OzgCloudLongClientAttribute;
import de.ozgcloud.apilib.client_attribute.OzgCloudStringClientAttribute;
import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcClientAttribute;
import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcClientAttributeValue;

@Mapper(nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS, unmappedTargetPolicy = ReportingPolicy.WARN)
public interface OzgCloudClientAttributeMapper {

	@Mapping(target = "valueOrBuilder", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "mergeValue", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "clientNameBytes", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "attributeNameBytes", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "accessValue", ignore = true)
	GrpcClientAttribute toGrpc(OzgCloudBooleanClientAttribute attribute);

	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "stringValueBytes", ignore = true)
	@Mapping(target = "stringValue", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "intValue", ignore = true)
	@Mapping(target = "doubleValue", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "allFields", ignore = true)

	@Mapping(target = "boolValue", source = "value")
	GrpcClientAttributeValue toValue(Boolean value);

	@Mapping(target = "valueOrBuilder", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "mergeValue", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "clientNameBytes", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "attributeNameBytes", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "accessValue", ignore = true)
	GrpcClientAttribute toGrpc(OzgCloudStringClientAttribute attribute);

	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "stringValueBytes", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "intValue", ignore = true)
	@Mapping(target = "doubleValue", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "boolValue", ignore = true)
	@Mapping(target = "allFields", ignore = true)

	@Mapping(target = "stringValue", source = "value")
	GrpcClientAttributeValue toValue(String value);

	@Mapping(target = "valueOrBuilder", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "mergeValue", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "clientNameBytes", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "attributeNameBytes", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "accessValue", ignore = true)
	GrpcClientAttribute toGrpc(OzgCloudLongClientAttribute attribute);

	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "stringValueBytes", ignore = true)
	@Mapping(target = "stringValue", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "doubleValue", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "boolValue", ignore = true)
	@Mapping(target = "allFields", ignore = true)

	@Mapping(target = "intValue", source = "value")
	GrpcClientAttributeValue toValue(Long value);

	@Mapping(target = "valueOrBuilder", ignore = true)
	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "mergeValue", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "clientNameBytes", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "attributeNameBytes", ignore = true)
	@Mapping(target = "allFields", ignore = true)
	@Mapping(target = "accessValue", ignore = true)
	GrpcClientAttribute toGrpc(OzgCloudDoubleClientAttribute attribute);

	@Mapping(target = "unknownFields", ignore = true)
	@Mapping(target = "stringValueBytes", ignore = true)
	@Mapping(target = "stringValue", ignore = true)
	@Mapping(target = "mergeUnknownFields", ignore = true)
	@Mapping(target = "mergeFrom", ignore = true)
	@Mapping(target = "intValue", ignore = true)
	@Mapping(target = "defaultInstanceForType", ignore = true)
	@Mapping(target = "clearOneof", ignore = true)
	@Mapping(target = "clearField", ignore = true)
	@Mapping(target = "boolValue", ignore = true)
	@Mapping(target = "allFields", ignore = true)

	@Mapping(target = "doubleValue", source = "value")
	GrpcClientAttributeValue toValue(Double value);
}
