/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.vorgang;

import java.util.List;

public class OzgCloudAntragstellerTestFactory {

	public static final String ANREDE = "Mr.";

	public static final String FIRSTNAME = "Theo";
	public static final String NACHNAME = "Test";
	public static final String GEBURTSDATUM = "10.04.1995";
	public static final String GEBURTSORT = "Downtown";
	public static final String GEBURTSNAME = "Toast";
	public static final String STRASSE = "Treestreet";
	public static final String HAUSNUMMER = "5a";
	public static final String PLZ = "12345";
	public static final String ORT = "City";
	public static final String E_MAIL = "test@local";
	public static final String TELEFON = "0123 2354 546";
	public static final String FIRMA_NAME = "TestFirma";

	public static final String FIELD_NAME = "name";
	public static final String FIELD_LABEL = "label";
	public static final String FIELD_VALUE = "value";
	public static final String SUB_FORM_NAME = "sub-form-name";
	public static final String SUB_FORM_LABEL = "sub-form-label";
	public static final String SUB_FORM_FIELD_NAME = "sub-form-field-name";
	public static final String SUB_FORM_FIELD_LABEL = "sub-form-field-label";
	public static final String SUB_FORM_FIELD_VALUE = "sub-form-field-value";

	public static OzgCloudAntragsteller create() {
		return createBuilder().build();
	}

	public static OzgCloudAntragsteller.OzgCloudAntragstellerBuilder createBuilder() {
		return OzgCloudAntragsteller.builder()
				.anrede(ANREDE)
				.vorname(FIRSTNAME)
				.nachname(NACHNAME)
				.firmaName(FIRMA_NAME)
				.geburtsdatum(GEBURTSDATUM)
				.geburtsort(GEBURTSORT)
				.geburtsname(GEBURTSNAME)
				.strasse(STRASSE)
				.hausnummer(HAUSNUMMER)
				.plz(PLZ)
				.ort(ORT)
				.email(E_MAIL)
				.telefon(TELEFON)
				.otherData(createOtherData());
	}

	public static List<OzgCloudFormDataEntry> createOtherData() {
		return List.of(
			OzgCloudFormField.builder().name(FIELD_NAME).label(FIELD_LABEL).value(FIELD_VALUE).build(),
			OzgCloudSubForm.builder().name(SUB_FORM_NAME).label(SUB_FORM_LABEL)
				.formEntry(OzgCloudFormField.builder().name(SUB_FORM_FIELD_NAME).label(SUB_FORM_FIELD_LABEL).value(SUB_FORM_FIELD_VALUE).build())
				.build()
		);
	}
}
